"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.setUpSocketIOPing = exports.appendQueryParams = exports.parseSocketIOUrl = void 0;

var _constants = require("./constants");

const parseSocketIOUrl = url => {
  if (url) {
    const isSecure = /^https|wss/.test(url);
    const strippedProtocol = url.replace(/^(https?|wss?)(:\/\/)?/, '');
    const removedFinalBackSlack = strippedProtocol.replace(/\/$/, '');
    const protocol = isSecure ? 'wss' : 'ws';
    return `${protocol}://${removedFinalBackSlack}${_constants.SOCKET_IO_PATH}`;
  }

  return url;
};

exports.parseSocketIOUrl = parseSocketIOUrl;

const appendQueryParams = function (url) {
  let params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  let alreadyHasParams = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
  const stringified = `${Object.entries(params).reduce((next, _ref) => {
    let [key, value] = _ref;
    return next + `${key}=${value}&`;
  }, '').slice(0, -1)}`;
  return `${url}${alreadyHasParams ? '&' : '?'}${stringified}`;
};

exports.appendQueryParams = appendQueryParams;

const setUpSocketIOPing = socketInstance => {
  const ping = () => socketInstance.send(_constants.SOCKET_IO_PING_CODE);

  return setInterval(ping, _constants.SOCKET_IO_PING_INTERVAL);
};

exports.setUpSocketIOPing = setUpSocketIOPing;
//# sourceMappingURL=socket-io.js.map