import { sharedWebSockets } from './globals';
import { DEFAULT_RECONNECT_LIMIT, DEFAULT_RECONNECT_INTERVAL_MS, ReadyState } from './constants';
import { getSubscribers } from './manage-subscribers';
export const attachSharedListeners = (webSocketInstance, url) => {
  webSocketInstance.onmessage = message => {
    getSubscribers(url).forEach(subscriber => {
      if (subscriber.optionsRef.current.onMessage) {
        subscriber.optionsRef.current.onMessage(message);
      }

      if (typeof subscriber.optionsRef.current.filter === 'function' && subscriber.optionsRef.current.filter(message) !== true) {
        return;
      }

      subscriber.setLastMessage(message);
    });
  };

  webSocketInstance.onclose = event => {
    getSubscribers(url).forEach(subscriber => {
      if (subscriber.optionsRef.current.onClose) {
        subscriber.optionsRef.current.onClose(event);
      }

      subscriber.setReadyState(ReadyState.CLOSED);
    });
    delete sharedWebSockets[url];
    getSubscribers(url).forEach(subscriber => {
      if (subscriber.optionsRef.current.shouldReconnect && subscriber.optionsRef.current.shouldReconnect(event)) {
        var _subscriber$optionsRe;

        const reconnectAttempts = (_subscriber$optionsRe = subscriber.optionsRef.current.reconnectAttempts) !== null && _subscriber$optionsRe !== void 0 ? _subscriber$optionsRe : DEFAULT_RECONNECT_LIMIT;

        if (subscriber.reconnectCount.current < reconnectAttempts) {
          if (subscriber.reconnectCount.current++ === 0) {
            subscriber.reconnect.current();
          } else {
            var _subscriber$optionsRe2;

            setTimeout(() => {
              subscriber.reconnect.current();
            }, (_subscriber$optionsRe2 = subscriber.optionsRef.current.reconnectInterval) !== null && _subscriber$optionsRe2 !== void 0 ? _subscriber$optionsRe2 : DEFAULT_RECONNECT_INTERVAL_MS);
          }
        } else {
          subscriber.optionsRef.current.onReconnectStop && subscriber.optionsRef.current.onReconnectStop(subscriber.optionsRef.current.reconnectAttempts);
          console.error(`Max reconnect attempts of ${reconnectAttempts} exceeded`);
        }
      }
    });
  };

  webSocketInstance.onerror = error => {
    getSubscribers(url).forEach(subscriber => {
      if (subscriber.optionsRef.current.onError) {
        subscriber.optionsRef.current.onError(error);
      }
    });
  };

  webSocketInstance.onopen = () => {
    getSubscribers(url).forEach(subscriber => {
      subscriber.reconnectCount.current = 0;

      if (subscriber.optionsRef.current.onOpen) {
        subscriber.optionsRef.current.onOpen();
      }

      subscriber.setReadyState(ReadyState.OPEN);
    });
  };
};
//# sourceMappingURL=attach-shared-listeners.js.map