import { useEffect, useRef, useState, useCallback, useMemo } from 'react';
import { closeWebSocket } from './close';
import { DEFAULT_OPTIONS, ReadyState, UNPARSABLE_JSON_OBJECT } from './constants';
import { createOrJoinSocket } from './create-or-join';
import { getUrl } from './get-url';
import websocketWrapper from './proxy';
export const useWebSocket = function (url) {
  let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : DEFAULT_OPTIONS;
  let connect = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
  const [lastMessage, setLastMessage] = useState({});
  const [readyState, setReadyState] = useState({});
  const lastJsonMessage = useMemo(() => {
    if (lastMessage) {
      try {
        return JSON.parse(lastMessage.data);
      } catch (e) {
        return UNPARSABLE_JSON_OBJECT;
      }
    }

    return null;
  }, [lastMessage]);
  const convertedUrl = useRef("");
  const webSocketRef = useRef(null);
  const startRef = useRef(() => {});
  const reconnectCount = useRef(0);
  const messageQueue = useRef([]);
  const webSocketProxy = useRef(null);
  const optionsCache = useRef(options);
  const readyStateFromUrl = convertedUrl.current && readyState[convertedUrl.current] !== undefined ? readyState[convertedUrl.current] : url !== null && connect === true ? ReadyState.CONNECTING : ReadyState.UNINSTANTIATED;
  const stringifiedQueryParams = options.queryParams ? JSON.stringify(options.queryParams) : null;
  const sendMessage = useCallback(message => {
    if (webSocketRef.current && webSocketRef.current.readyState === ReadyState.OPEN) {
      webSocketRef.current.send(message);
    } else {
      messageQueue.current.push(message);
    }
  }, []);
  const sendJsonMessage = useCallback(message => {
    sendMessage(JSON.stringify(message));
  }, [sendMessage]);
  const getWebSocket = useCallback(() => {
    var _optionsCache$current;

    if (((_optionsCache$current = optionsCache.current) === null || _optionsCache$current === void 0 ? void 0 : _optionsCache$current.share) !== true && null !== webSocketRef.current) {
      return webSocketRef.current;
    }

    if (webSocketProxy.current === null && webSocketRef.current && startRef.current) {
      webSocketProxy.current = websocketWrapper(webSocketRef.current, startRef);
    } else {
      return webSocketProxy.current;
    }

    return webSocketProxy.current;
  }, [optionsCache]);

  const closeSocket = () => closeWebSocket(convertedUrl.current);

  useEffect(() => {
    if (url !== null && connect === true) {
      let removeListeners;
      let expectClose = false;

      const start = async () => {
        convertedUrl.current = await getUrl(url, optionsCache);

        const protectedSetLastMessage = message => {
          if (!expectClose) {
            setLastMessage(message);
          }
        };

        const protectedSetReadyState = state => {
          if (!expectClose) {
            setReadyState(prev => ({ ...prev,
              [convertedUrl.current]: state
            }));
          }
        };

        removeListeners = createOrJoinSocket(webSocketRef, convertedUrl.current, protectedSetReadyState, optionsCache, protectedSetLastMessage, startRef, reconnectCount);
      };

      startRef.current = () => {
        if (!expectClose) {
          var _removeListeners;

          if (webSocketProxy.current) webSocketProxy.current = null;
          (_removeListeners = removeListeners) === null || _removeListeners === void 0 ? void 0 : _removeListeners();
          start();
        }
      };

      start();
      return () => {
        var _removeListeners2;

        expectClose = true;
        if (webSocketProxy.current) webSocketProxy.current = null;
        (_removeListeners2 = removeListeners) === null || _removeListeners2 === void 0 ? void 0 : _removeListeners2();
        setLastMessage({});
      };
    } else {
      return;
    }
  }, [url, connect, stringifiedQueryParams, optionsCache, sendMessage]);
  useEffect(() => {
    if (readyStateFromUrl === ReadyState.OPEN) {
      messageQueue.current.splice(0).forEach(message => {
        sendMessage(message);
      });
    }
  }, [readyStateFromUrl]);
  return {
    sendMessage,
    sendJsonMessage,
    lastMessage,
    lastJsonMessage,
    readyState: readyStateFromUrl,
    getWebSocket,
    closeSocket
  };
};
//# sourceMappingURL=use-websocket.js.map